@@ -30,7 +30,7 @@ import pendulum
 from typic.ext.json import dumps
 from typic.serde.common import SerdeFlags
 from typic.serde.resolver import resolver
-from typic.util import filtered_repr, cached_property
+from typic.util import filtered_repr, cached_property, TypeMap
 from typic.types import dsn, email, frozendict, path, secret, url
 from .compat import fastjsonschema
 
@@ -334,21 +334,8 @@ def get_field_type(type: Optional[Union[SchemaType, Any]]) -> Type[SchemaFieldT]
     return TYPE_TO_FIELD[type]
 
 
-SCHEMA_FIELD_FORMATS: frozendict.FrozenDict[type, SchemaFieldT] = frozendict.FrozenDict(
+SCHEMA_FIELD_FORMATS = TypeMap(
     {
-        str: StrSchemaField(),
-        AnyStr: StrSchemaField(),
-        Text: StrSchemaField(),
-        bytes: StrSchemaField(),
-        int: IntSchemaField(),
-        bool: BooleanSchemaField(),
-        float: NumberSchemaField(),
-        list: ArraySchemaField(),
-        set: ArraySchemaField(uniqueItems=True),
-        tuple: ArraySchemaField(additionalItems=False),
-        frozenset: ArraySchemaField(uniqueItems=True, additionalItems=False),
-        dict: ObjectSchemaField(),
-        object: UndeclaredSchemaField(),
         frozendict.FrozenDict: ObjectSchemaField(),
         decimal.Decimal: NumberSchemaField(),
         datetime.datetime: StrSchemaField(format=StringFormat.DTIME),
@@ -372,6 +359,18 @@ SCHEMA_FIELD_FORMATS: frozendict.FrozenDict[type, SchemaFieldT] = frozendict.Fro
         re.Pattern: StrSchemaField(format=StringFormat.RE),  # type: ignore
         ipaddress.IPv4Address: StrSchemaField(format=StringFormat.IPV4),
         ipaddress.IPv6Address: StrSchemaField(format=StringFormat.IPV6),
+        str: StrSchemaField(),
+        AnyStr: StrSchemaField(),
+        Text: StrSchemaField(),
+        bytes: StrSchemaField(),
+        bool: BooleanSchemaField(),
+        int: IntSchemaField(),
+        float: NumberSchemaField(),
+        list: ArraySchemaField(),
+        set: ArraySchemaField(uniqueItems=True),
+        tuple: ArraySchemaField(additionalItems=False),
+        frozenset: ArraySchemaField(uniqueItems=True, additionalItems=False),
+        dict: ObjectSchemaField(),
         type(None): NullSchemaField(),
     }
 )
