@@ -13,6 +13,7 @@ from typing import (
     Generic,
     cast,
     Set,
+    AnyStr,
 )
 
 import inflection  # type: ignore
@@ -22,6 +23,7 @@ from typic.serde.resolver import resolver
 from typic.serde.common import SerdeProtocol, Annotation
 from typic.compat import Final, TypedDict
 from typic.util import get_args, origin
+from typic.checks import istypeddict, isnamedtuple
 from typic.types.frozendict import FrozenDict
 
 from .field import (  # type: ignore
@@ -41,6 +43,9 @@ _IGNORE_DOCS = frozenset({Mapping.__doc__, Generic.__doc__, List.__doc__})
 __all__ = ("SchemaBuilder", "SchemaDefinitions", "builder")
 
 
+_KNOWN = (*(f for f in SCHEMA_FIELD_FORMATS.keys() if f not in {AnyStr, object}),)
+
+
 class SchemaDefinitions(TypedDict):
     """A :py:class:`TypedDict` for JSON Schema Definitions."""
 
@@ -128,8 +133,6 @@ class SchemaBuilder:
         # If a field isn't required an empty default is functionally the same
         # as a default to None for the JSON schema.
         default = anno.parameter.default if anno.has_default else None
-        # Get known schemas mapped to Python types.
-        formats = SCHEMA_FIELD_FORMATS
         # `use` is the based annotation we will use for building the schema
         use = getattr(anno.origin, "__parent__", anno.origin)
         # If there's not a static annotation, short-circuit the rest of the checks.
@@ -176,7 +179,14 @@ class SchemaBuilder:
             ro = None
 
         # If we've got a base object, use it
-        if use in formats:
+        base: Optional[SchemaFieldT]
+        if use is object:
+            base = UndeclaredSchemaField()
+        elif istypeddict(use) or isnamedtuple(use):
+            base = None
+        else:
+            base = cast(SchemaFieldT, SCHEMA_FIELD_FORMATS.get_by_parent(use))
+        if base:
             constraints = (
                 protocol.constraints.for_schema() if protocol.constraints else {}
             )
@@ -187,7 +197,6 @@ class SchemaBuilder:
                 self._handle_mapping(anno, constraints, name=name)
             elif use in {tuple, set, frozenset, list}:
                 self._handle_array(anno, constraints)
-            base: SchemaFieldT = formats[use]
             schema = dataclasses.replace(base, **constraints)
         else:
             schema = self.build_schema(use, name=self.defname(use, name=name))
